@@ -102,8 +102,8 @@ def deploy(t: str) -> None:
 def say_message() -> None:
 
     message = (
-        "Lia is an open-source CI/CD tool that eliminates the Fel"
-        "Copyright © 2023 Soul Twin Records, as subsidiary of SailBlack Inc."
+        "U+1FAC Lia is an open-source CI/CD tool that eliminates the Fel U+1F9BE"
+        " Copyright © 2023 Soul Twin Records U+1F919, a subsidiary of SailBlack Inc."
     )
     echo(message=message)
 
